summaryrefslogtreecommitdiff
path: root/test/unit/node/node_black.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/node/node_black.cpp')
-rw-r--r--test/unit/node/node_black.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/unit/node/node_black.cpp b/test/unit/node/node_black.cpp
index 3c1651155..7ae8a9434 100644
--- a/test/unit/node/node_black.cpp
+++ b/test/unit/node/node_black.cpp
@@ -9,9 +9,9 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief Black box testing of CVC4::Node.
**
** Black box testing of CVC4::Node.
**/
#include <algorithm>
@@ -30,7 +30,7 @@
#include "test_node.h"
#include "theory/rewriter.h"
-namespace CVC4 {
+namespace CVC5 {
using namespace kind;
@@ -784,4 +784,4 @@ TEST_F(TestNodeBlackNode, node_tnode_usage)
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,9 +9,9 @@
** directory for licensing information.\endverbatim
**
- ** \brief Black box testing of CVC4::Node.
+ ** \brief Black box testing of CVC5::Node.
**
@@ -9,9 +9,9 @@
**
- ** Black box testing of CVC4::Node.
+ ** Black box testing of CVC5::Node.
**/
#include <algorithm>